@@ -1,7 +1,7 @@
 from pyramid.view import view_config
 
 from ..models import (
-    DBSession,
+    db,
     #include your models here
     )
 
