@@ -232,14 +232,17 @@ class CRUDController(object):
         if self.add_edit_exclude:
             return self.add_edit_exclude
 
+        print('determining exclude list')
         # exclude any relationships
         exclude_list = self.model.__mapper__.relationships.keys()
+        print(exclude_list)
 
         if 'add' == action_type:
-            # get the columns and add any primary key columns to the exlude list if their autoincrement is True
+            # get the columns and add any primary key columns to the
+            # exlude list if their autoincrement is True
             cols = get_columns(self.model, 'primary_key')
             for c in cols:
-                if int == c.property.columns[0].type.python_type:
+                if int == c.property.columns[0].type.python_type and 0 == len(c.property.columns[0].foreign_keys):
                     exclude_list.append(c.key)
 
         return exclude_list
@@ -271,7 +274,6 @@ class CRUDController(object):
             columns = self.model.__table__.columns.keys()
 
         # calculate number of pages
-        # TODO: Would need modifications for composite primary keys
         pk_col = self.model.__table__.primary_key.columns.keys()[0]
         pk_col = self.model.__table__.primary_key.columns[pk_col]
 
@@ -325,7 +327,16 @@ class CRUDController(object):
                 #field.validators = []
 
             if 'choices_fields' in field_data:
-                field.choices = self.db_session.query(*field_data['choices_fields']).all()
+                recs = self.db_session.query(*field_data['choices_fields']).all()
+
+                table_cols = get_columns(self.model)
+                for table_col in table_cols:
+                    if table_col.property.columns[0].name == field_name and \
+                    table_col.property.columns[0].nullable:
+                        field.validators = []
+                        recs.insert(0, (None, ''))
+
+                field.choices = recs
                 #field.validators = []
 
         return f
@@ -343,7 +354,12 @@ class CRUDController(object):
             #if f.validate():
             if True:
                 obj = self.model()
+                for fname, f_field in f._fields.iteritems():
+                    if hasattr(f_field, 'choices') and '' == f_field.data:
+                        f_field.data = None
+
                 f.populate_obj(obj)
+                #assert False
                 self.db_session.add(obj)
 
                 self.request.session.flash(self.friendly_name + " added successfully!")
